package VMOMI::HostInternetScsiHbaChapAuthenticationType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
